@@ -6,6 +6,6 @@
 #ifndef RNVideoTrimmer_Bridging_Header_h
 #define RNVideoTrimmer_Bridging_Header_h
 
-#import "RCTBridgeModule.h"
+#import "React/RCTBridgeModule.h"
 
 #endif /* RNVideoTrimmer_Bridging_Header_h */
